==> bsflite-0.80.tar.gz: bsflite-0.80/config.c <==
/**
 ** bsflite - bs-free AIM client
 **
 ** (C) 2003-2005 by Claudio Leite <leitec at leitec dot org>
 **
 ** NO WARRANTY. Read the file COPYING for more details.
 **/

#include "bsf.h"

extern struct Conn *conn;

/* PROTO */
int
read_conf(void)
{
	FILE           *conf;
	int             haspw = 0, hasuser = 0, linecount = 0;
	char            buf[1024];
	char           *tptr;
#if !defined(__MINGW32__) && !defined(__DJGPP__)
	char           *home;

#ifdef PLAN9
	if ((home = getenv("home")) == NULL)
		home = ".";

	sprintf(buf, "%s/lib/bsflite/config", home);
#else
	if ((home = getenv("HOME")) == NULL)
		home = ".";

	sprintf(buf, "%s/.bsflite/config", home);
#endif				/* PLAN9 */

#else
	sprintf(buf, "config.txt");
#endif

	conf = fopen(buf, "r");
	if (conf == NULL)
		return -1;

	while (!feof(conf)) {
		linecount++;
		memset(buf, 0, sizeof(buf));
		fgets(buf, sizeof(buf), conf);

		if (buf[0] == '#')
			continue;

		tptr = strchr(buf, '\n');
		if (tptr != NULL)
			tptr[0] = 0;

		tptr = strchr(buf, ' ');
		if (tptr == NULL)
			continue;

		if (strncmp(buf, "username ", 9) == 0) {
			conn->username = strdup(tptr + 1);
			hasuser = 1;
		} else if (strncmp(buf, "password ", 9) == 0) {
			conn->password = strdup(tptr + 1);
			haspw = 1;
		} else if (strncmp(buf, "squelchconnect true", 19) == 0) {
			conn->squelchconnect = 1;
		} else if (strncmp(buf, "squelchidle true", 16) == 0) {
			conn->squelchidle = 1;
		} else if (strncmp(buf, "squelchaway true", 16) == 0) {
			conn->squelchaway = 1;
		} else if (strncmp(buf, "respond_idle_only true", 22) == 0) {
			conn->respond_idle_only = 1;
		} else if (strncmp(buf, "report_idle false", 17) == 0) {
			conn->report_idle = 0;
		} else if (strncmp(buf, "netspeak_filter true", 20) == 0) {
			conn->netspeak_filter = 1;
		} else {
			printf("** Line %d: invalid option '%s'\n", linecount, buf);
		}
	}

	fclose(conf);

	if (haspw && hasuser)
		return 1;
	else if (hasuser)
		return 2;
	else
		return 0;
}

==> bsflite-0.81.tar.gz: bsflite-0.81/config.c <==
/**
 ** bsflite - bs-free AIM client
 **
 ** (C) 2003-2005 by Claudio Leite <leitec at leitec dot org>
 **
 ** NO WARRANTY. Read the file COPYING for more details.
 **/

#include "bsf.h"

extern struct Conn *conn;

/* PROTO */
int
read_conf(void)
{
	FILE           *conf;
	int             haspw = 0, hasuser = 0, linecount = 0;
	char            buf[1024];
	char           *tptr;
#if !defined(__MINGW32__) && !defined(__DJGPP__)
	char           *home;

#ifdef PLAN9
	if ((home = getenv("home")) == NULL)
		home = ".";

	snprintf(buf, sizeof(buf), "%s/lib/bsflite/config", home);
#else
	if ((home = getenv("HOME")) == NULL)
		home = ".";

	snprintf(buf, sizeof(buf), "%s/.bsflite/config", home);
#endif				/* PLAN9 */

#else
	snprintf(buf, sizeof(buf), "config.txt");
#endif

	conf = fopen(buf, "r");
	if (conf == NULL)
		return -1;

	while (!feof(conf)) {
		linecount++;
		memset(buf, 0, sizeof(buf));
		fgets(buf, sizeof(buf), conf);

		if (buf[0] == '#')
			continue;

		tptr = strchr(buf, '\n');
		if (tptr != NULL)
			tptr[0] = 0;

		tptr = strchr(buf, ' ');
		if (tptr == NULL)
			continue;

		/*
		 * I do plan on turning this into a
		 * real config file parser at some time.
		 */

		if (strncmp(buf, "username ", 9) == 0) {
			conn->username = strdup(tptr + 1);
			hasuser = 1;
		} else if (strncmp(buf, "password ", 9) == 0) {
			conn->password = strdup(tptr + 1);
			haspw = 1;
		} else if (strncmp(buf, "proxy ", 6) == 0) {
			conn->proxy = strdup(tptr + 1);
		} else if (strncmp(buf, "proxyport ", 10) == 0) {
			conn->proxyport = atoi(tptr + 1);
		} else if (strncmp(buf, "proxytype ", 10) == 0) {
			if (strncmp(tptr + 1, "socks5", 6) == 0) {
				conn->proxytype = PROXY_TYPE_SOCKS5;
			} else if (strncmp(tptr + 1, "https", 5) == 0) {
				conn->proxytype = PROXY_TYPE_HTTPS;
			}
		} else if (strncmp(buf, "squelchconnect true", 19) == 0) {
			conn->squelchconnect = 1;
		} else if (strncmp(buf, "squelchidle true", 16) == 0) {
			conn->squelchidle = 1;
		} else if (strncmp(buf, "squelchaway true", 16) == 0) {
			conn->squelchaway = 1;
		} else if (strncmp(buf, "respond_idle_only true", 22) == 0) {
			conn->respond_idle_only = 1;
		} else if (strncmp(buf, "report_idle false", 17) == 0) {
			conn->report_idle = 0;
		} else if (strncmp(buf, "netspeak_filter true", 20) == 0) {
			conn->netspeak_filter = 1;
		} else if (strncmp(buf, "timestamps false", 16) == 0) {
			conn->timestamps = 0;
		} else if (strncmp(buf, "oscarport ", 10) == 0) {
			conn->oscarport = atoi(tptr + 1);
		} else if (strncmp(buf, "set_window_title true", 21) == 0) {
			conn->set_window_title = 1;
		} else if (strncmp(buf, "bell_on_incoming true", 21) == 0) {
			conn->bell_on_incoming = 1;
		} else {
			printf("** Line %d: invalid option '%s'\n", linecount, buf);
		}
	}

	fclose(conf);

	if (haspw && hasuser)
		return 1;
	else if (hasuser)
		return 2;
	else
		return 0;
}
